@@ -1,4 +1,4 @@
 from typing import Any, Dict, Union
 import os
 
-StrPath = Union[str, os.PathLike[str]]
+StrPath = Union[str, os.PathLike]
